@@ -28,7 +28,7 @@ BEGIN {
     }
 }
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 sub _ANYPROCESS                    { return -1 }
 sub _COMMAND                       { return 0 }
@@ -438,21 +438,17 @@ sub error_message {
             || ( POSIX::WIFSIGNALED($child_error) ) )
         {
             if ( POSIX::WIFEXITED($child_error) ) {
-                if ( $child_error == 0 ) {
-                }
-                else {
-                    $message =
-                      'Exited with ' . POSIX::WEXITSTATUS($child_error);
-                }
+                $message =
+                  'Firefox exited with a ' . POSIX::WEXITSTATUS($child_error);
             }
             elsif ( POSIX::WIFSIGNALED($child_error) ) {
                 my $name = $self->_signal_name( POSIX::WTERMSIG($child_error) );
                 if ( defined $name ) {
-                    $message = "Killed by $name signal ("
+                    $message = "Firefox killed by a $name signal ("
                       . POSIX::WTERMSIG($child_error) . q[)];
                 }
                 else {
-                    $message = 'Killed by signal ('
+                    $message = 'Firefox killed by a signal ('
                       . POSIX::WTERMSIG($child_error) . q[)];
                 }
             }
@@ -461,16 +457,16 @@ sub error_message {
             if ( POSIX::WIFSTOPPED($child_error) ) {
                 my $name = $self->_signal_name( POSIX::WTERMSIG($child_error) );
                 if ( defined $name ) {
-                    $message = "Stopped by $name signal ("
+                    $message = "Firefox stopped by a $name signal ("
                       . POSIX::WSTOPSIG($child_error) . q[)];
                 }
                 else {
-                    $message = 'Stopped by signal ('
+                    $message = 'Firefox stopped by a signal ('
                       . POSIX::WSTOPSIG($child_error) . q[)];
                 }
             }
             elsif ( POSIX::WIFCONTINUED($child_error) ) {
-                $message = 'Continuing';
+                $message = 'Firefox continuing';
             }
         }
     }
@@ -556,10 +552,8 @@ sub _setup_local_connection_to_firefox {
     }
     else {
         my $error_message =
-          $self->error_message() ? q[:] . $self->error_message() : q[];
-        Carp::croak( q[Firefox failed to start as ']
-              . ( join q[ ], $binary, @arguments )
-              . $error_message );
+          $self->error_message() ? $self->error_message() : q[];
+        Carp::croak( $error_message );
     }
     return $socket;
 }
@@ -1801,7 +1795,7 @@ Firefox::Marionette - Automate the Firefox browser with the Marionette protocol
 
 =head1 VERSION
 
-Version 0.24
+Version 0.25
 
 =head1 SYNOPSIS
 
